Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/external/bsd/flex/dist rename warn -> lwarn to use the pre-g...



details:   https://anonhg.NetBSD.org/src/rev/9b74e1c9ef60
branches:  trunk
changeset: 748540:9b74e1c9ef60
user:      christos <christos%NetBSD.org@localhost>
date:      Mon Oct 26 19:23:19 2009 +0000

description:
rename warn -> lwarn to use the pre-generated parse.c since our yacc is
not up to snuff yet.

diffstat:

 external/bsd/flex/dist/parse.c |  22 +++++++++++-----------
 1 files changed, 11 insertions(+), 11 deletions(-)

diffs (81 lines):

diff -r 20b508ced631 -r 9b74e1c9ef60 external/bsd/flex/dist/parse.c
--- a/external/bsd/flex/dist/parse.c    Mon Oct 26 19:16:54 2009 +0000
+++ b/external/bsd/flex/dist/parse.c    Mon Oct 26 19:23:19 2009 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: parse.c,v 1.1.1.1 2009/10/26 00:26:38 christos Exp $   */
+/*     $NetBSD: parse.c,v 1.2 2009/10/26 19:23:19 christos Exp $       */
 
 /* A Bison parser, made by GNU Bison 2.1.  */
 
@@ -206,7 +206,7 @@
        do{ \
         char fw3_msg[MAXLINE];\
         snprintf( fw3_msg, MAXLINE,(fmt), (a1), (a2) );\
-        warn( fw3_msg );\
+        lwarn( fw3_msg );\
        }while(0)
 
 /* Expand a POSIX character class expression. */
@@ -1618,7 +1618,7 @@
                                                scon_stk[++scon_stk_ptr] = i;
 
                                if ( scon_stk_ptr == 0 )
-                                       warn(
+                                       lwarn(
                        "all start conditions already have <<EOF>> rules" );
 
                                else
@@ -1720,7 +1720,7 @@
                                 * erroneously.
                                 */
                                if ( ! varlength || headcnt != 0 )
-                                       warn(
+                                       lwarn(
                "trailing context made variable due to preceding '|' action" );
 
                                /* Mark as variable. */
@@ -1779,7 +1779,7 @@
                                /* See the comment in the rule for "re2 re"
                                 * above.
                                 */
-                               warn(
+                               lwarn(
                "trailing context made variable due to preceding '|' action" );
 
                                varlength = true;
@@ -2378,7 +2378,7 @@
 #line 916 "parse.y"
     { 
                                if ( sf_case_ins() )
-                                       warn(_("[:^lower:] is ambiguous in case insensitive scanner"));
+                                       lwarn(_("[:^lower:] is ambiguous in case insensitive scanner"));
                                else
                                        CCL_NEG_EXPR(islower);
                                }
@@ -2388,7 +2388,7 @@
 #line 922 "parse.y"
     {
                                if ( sf_case_ins() )
-                                       warn(_("[:^upper:] ambiguous in case insensitive scanner"));
+                                       lwarn(_("[:^upper:] ambiguous in case insensitive scanner"));
                                else
                                        CCL_NEG_EXPR(isupper);
                                }
@@ -2760,13 +2760,13 @@
        char warn_msg[MAXLINE];
 
        snprintf( warn_msg, sizeof(warn_msg), msg, arg );
-       warn( warn_msg );
+       lwarn( warn_msg );
        }
 
 
-/* warn - report a warning, unless -w was given */
-
-void warn( str )
+/* lwarn - report a warning, unless -w was given */
+
+void lwarn( str )
 const char *str;
        {
        line_warning( str, linenum );



Home | Main Index | Thread Index | Old Index